
function ss = SSsyn01(PS, k1, k2, NN, JJ, Amp)

%% Synthesize a Swept Sine (SS) signal
%
% PS: Power spectrum
% k1: Frequency number where group delay D(k1)=0
% k2: Frequency number where group delay D(k2)=JJ
% NN: Signal length
% JJ: Effective length
% Amp: Signal amplitude

%%
% --- Group delay

gd = cumsum(PS);                      % Integration

C1 = sum(PS(1:k1+1));                 % to make group delay D(k1)=0 
C2 = JJ/sum(PS(k1+2:k2+1));           % to make group delay D(k2)=JJ 

gd = C2 * (gd - C1);

% --- Phase
ph = 2*pi/NN * (cumsum(gd) - gd(1));  % ph(k)=0 for k=0
ph = ph * ( round( ph(NN/2+1)/pi)* pi/ph(NN/2+1));
                                      % ph(k)=m\pi for k=NN/2 

% --- Amplitude
Den = sum(PS);                               % signal energy
AM = Amp*sqrt(JJ)*sqrt(PS)*sqrt((NN/2)/Den)/sqrt(2); % calculate amplitude

% --- Signal synthesis
SS(1:NN/2+1) = AM.*exp(-j*ph);               % Signal spectrum
SS( NN/2+2 : NN) = conj(fliplr(SS(2:NN/2))); % Negative frequency
ss =real(ifft(SS));                          % Transform into time domain

ss=[ss((NN+JJ)/2+1:NN), ss(1:(NN+JJ)/2)];    % Circular shift

return



