
%% Signal extraction using cross-fade method

function yy = cross_fade_01(rec, NN)

% NN: Signal period
% rec: Recorded signal containing two periods
% yy: extracted signal using cross-fade method


% Ver. 1.0;   2013.8.28 TDU R. Nakashige & Y. Kaneda

% kaneda@c.dendai.ac.jp

% -----------------------------------------

rec0=rec; if_tp=0;
if size(rec0,1)<size(rec0,2); rec0 = rec0'; if_tp=1; end;  %  Set rec0 as a column vector 
Lw = 509;                  % Cross fade length 
                           % (a multiple of 4) +1 % about 10ms for 48 kHz sampling
ww = hanning(Lw);          % Window function
Lw2 = (Lw-1)/2;            % half-window length
Lw4 = (Lw-1)/4;            % 1/2 of half-window length

% --- Extract the Lw4 *2 + NN data
rec_cut = rec0(NN+1-Lw2:2*NN);

% --- Weighting on both ends ---
rec_cut(1:Lw2) = rec_cut(1:Lw2).*ww(1:Lw2);  % left end
rec_cut(end-Lw2+1:end) = rec_cut(end-Lw2+1:end).*ww(end-Lw2+1:end);  % right end
% --- Cyclic addition (add to the run-off portion at the opposite end) ---
yy = rec_cut(Lw4+1:end-Lw4);                    % yy is the center NN points
yy(1:Lw4) = yy(1:Lw4) + rec_cut(end-Lw4+1:end); % Lw4 data at the right end is added to the left end 
yy(end-Lw4+1:end) = yy(end-Lw4+1:end) + rec_cut(1:Lw4);  
                                                % Lw4 data at the left end
                                                % is added to the right end
yy = [yy(Lw4+1:end); yy(1:Lw4)];                % Circular shift of Lw4 point
                                                
if if_tp==1; yy = yy'; end                      % Align the yy in vector format of rec

return