
% mps21.m
% Mean power spectrum
function pspec = mps21(xxx, Lwind, Lshift, Nfft, www)

%%
% xxx   : signal 
% Lwind : wind length 
% Lshift: shift length (default value is Lwind/2)
% Nfft  : FFT length (including padded zeros)(default value is Lwind*2)
% www : wind function (default is Hanning)
%
% pspec : (Nfft x 1) array
%
% $Revision: 1.0 $  $Date: 2014/02/09 $
%

%%
% --- Default wind parameters -------------------------
% nargin
if nargin<5; www =hanning(Lwind); end; % Default is Hanning
if nargin<4; Nfft = Lwind * 2; end;    % Default is Lwind*2
if nargin<3; Lshift = Lwind /2; end;   % Default is Lwind/2

% --- Set xxx as a column vector -------------------------
sz = size(xxx);
if sz(1)>sz(2); xxx0 = xxx; else xxx0 = xxx'; end

% --- Calculate the mean power spectrum -------------------------
Nrep = floor((length(xxx0)-Lwind)/Lshift)+1; % fft times
pspec = zeros(Nfft,1);

for ii = 0:Nrep-1
    xxx1 = xxx0(Lshift*ii+1 : Lshift*ii+Lwind); % extraction
    xspc = fft(xxx1.*www, Nfft);
    pspec = pspec + xspc.*conj(xspc);
end

pspec = pspec/Nrep;  % mean
pspec = pspec/sum(www.^2); 
    % Normalization so as to be 0dB for a white noise whose rms is 1

return
